==> ejc-lz-impl-3.0.0-20220411.011057-38-sources.jar: com/ejianc/business/base/controller/ShippersController.java <==
package com.ejianc.business.base.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.*;
import com.ejianc.business.base.service.IShippersBankService;
import com.ejianc.business.base.service.IShippersLinkerService;
import com.ejianc.business.base.service.IShippersVehicleService;
import com.ejianc.business.base.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.base.service.IShippersService;

/**
 * 运输商基本档案
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("shippers")
public class ShippersController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "base-shippers";//此处需要根据实际修改

    @Autowired
    private IShippersService service;
    @Autowired
    private IShippersBankService shippersBankService;
    @Autowired
    private IShippersLinkerService shippersLinkerService;
    @Autowired
    private IShippersVehicleService shippersVehicleService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ShippersVO> saveOrUpdate(@RequestBody ShippersVO saveOrUpdateVO) {
    	ShippersEntity entity = BeanMapper.map(saveOrUpdateVO, ShippersEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        QueryWrapper query=new QueryWrapper();
        query.eq("name",entity.getName());
        query.eq("dr",0);
        List<ShippersEntity> list = service.list(query);
        if (list.size()>0){
            for (int i = 0; i < list.size(); i++) {
                ShippersEntity Entity = list.get(i);
                if (!String.valueOf(Entity.getId()).equals(String.valueOf(entity.getId()))){
//                    System.out.println(saveId == editId);
                    throw new BusinessException("运输商名称已存在，请修改运输商名称后保存");
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	ShippersVO vo = BeanMapper.map(entity, ShippersVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ShippersVO> queryDetail(Long id) {
    	ShippersEntity entity = service.selectById(id);
    	ShippersVO vo = BeanMapper.map(entity, ShippersVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ShippersVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ShippersVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ShippersVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ShippersVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ShippersEntity> page = service.queryPage(param,false);
        IPage<ShippersVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ShippersVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ShippersEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Shippers-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refShippersData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ShippersVO>> refShippersData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String orgId = _con.getString("orgId");
            if (orgId!=null) {
                param.getParams().put("org_id", new Parameter(QueryParam.EQ, orgId));
            }
        }

        IPage<ShippersEntity> page = service.queryPage(param,false);
        IPage<ShippersVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ShippersVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
    /***
     * @Description 查询客户联系人列表
     * @param shippersId
     * @return
     */
    @GetMapping(value = "queryLinkerByShippersId")
    @ResponseBody
    public CommonResponse<List<ShippersLinkerVO>> queryLinkerByShippersId(@RequestParam(value = "shippersId") Long shippersId) {
        QueryWrapper query=new QueryWrapper();
        query.eq("shipper_mid",shippersId);
        query.eq("dr",0);
        List<ShippersLinkerEntity> list = shippersLinkerService.list(query);
        List<ShippersLinkerVO> map = BeanMapper.mapList(list,ShippersLinkerVO.class);
        return CommonResponse.success("查询详情成功！", map);
    }
    /***
     * @Description 查询客户联系人列表
     * @param shippersId
     * @return
     */
    @GetMapping(value = "queryBankByShippersId")
    @ResponseBody
    public CommonResponse<List<ShippersBankVO>> queryBankByShippersId(@RequestParam(value = "shippersId") Long shippersId) {
        QueryWrapper query=new QueryWrapper();
        query.eq("shipper_mid",shippersId);
        query.eq("dr",0);
        List<ShippersBankEntity> list = shippersBankService.list(query);
        List<ShippersBankVO> map = BeanMapper.mapList(list,ShippersBankVO.class);
        return CommonResponse.success("查询详情成功！", map);
    }
    /***
     * @Description 查询客户联系人列表
     * @param shippersId
     * @return
     */
    @GetMapping(value = "queryVehicleByShippersId")
    @ResponseBody
    public CommonResponse<List<ShippersVehicleVO>> queryVehicleByShippersId(@RequestParam(value = "shippersId") Long shippersId) {
        QueryWrapper query=new QueryWrapper();
        query.eq("shipper_m_id",shippersId);
        query.eq("dr",0);
        List<ShippersVehicleEntity> list = shippersVehicleService.list(query);
        List<ShippersVehicleVO> map = BeanMapper.mapList(list,ShippersVehicleVO.class);
        return CommonResponse.success("查询详情成功！", map);
    }

}

==> ejc-lz-impl-3.0.0-20220421.012039-57-sources.jar: com/ejianc/business/base/controller/ShippersController.java <==
package com.ejianc.business.base.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.*;
import com.ejianc.business.base.service.IShippersBankService;
import com.ejianc.business.base.service.IShippersLinkerService;
import com.ejianc.business.base.service.IShippersVehicleService;
import com.ejianc.business.base.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.base.service.IShippersService;

/**
 * 运输商基本档案
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("shippers")
public class ShippersController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "base-shippers";//此处需要根据实际修改

    @Autowired
    private IShippersService service;
    @Autowired
    private IShippersBankService shippersBankService;
    @Autowired
    private IShippersLinkerService shippersLinkerService;
    @Autowired
    private IShippersVehicleService shippersVehicleService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ShippersVO> saveOrUpdate(@RequestBody ShippersVO saveOrUpdateVO) {
    	ShippersEntity entity = BeanMapper.map(saveOrUpdateVO, ShippersEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        QueryWrapper query=new QueryWrapper();
        query.eq("name",entity.getName());
        query.eq("dr",0);
        List<ShippersEntity> list = service.list(query);
        if (list.size()>0){
            for (int i = 0; i < list.size(); i++) {
                ShippersEntity Entity = list.get(i);
                if (!String.valueOf(Entity.getId()).equals(String.valueOf(entity.getId()))){
//                    System.out.println(saveId == editId);
                    throw new BusinessException("运输商名称已存在，请修改运输商名称后保存");
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	ShippersVO vo = BeanMapper.map(entity, ShippersVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ShippersVO> queryDetail(Long id) {
    	ShippersEntity entity = service.selectById(id);
    	ShippersVO vo = BeanMapper.map(entity, ShippersVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ShippersVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ShippersVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(ShippersVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ShippersVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ShippersEntity> page = service.queryPage(param,false);
        IPage<ShippersVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ShippersVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ShippersEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Shippers-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refShippersData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ShippersVO>> refShippersData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String orgId = _con.getString("orgId");
            if (orgId!=null) {
                param.getParams().put("org_id", new Parameter(QueryParam.EQ, orgId));
            }
        }

        IPage<ShippersEntity> page = service.queryPage(param,false);
        IPage<ShippersVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ShippersVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
    /***
     * @Description 查询客户联系人列表
     * @param shippersId
     * @return
     */
    @PostMapping(value = "queryLinkerByShippersId")
    @ResponseBody
    public CommonResponse<IPage<ShippersLinkerVO>> queryLinkerByShippersId(@RequestBody RequestVO requestVO) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageSize(requestVO.getPageSize());
        queryParam.setPageIndex(requestVO.getPageIndex());
        queryParam.setOrderMap(requestVO.getOrderMap());
        queryParam.getParams().put("shipper_mid",new Parameter(QueryParam.EQ,requestVO.getId()));
        IPage<ShippersLinkerEntity> page = shippersLinkerService.queryPage(queryParam, false);
        IPage<ShippersLinkerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ShippersLinkerVO.class));
        return CommonResponse.success("查询详情成功！", pageData);
    }
    /***
     * @Description 查询客户联系人列表
     * @param shippersId
     * @return
     */
    @PostMapping(value = "queryBankByShippersId")
    @ResponseBody
    public CommonResponse<IPage<ShippersBankVO>> queryBankByShippersId(@RequestBody RequestVO requestVO) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageSize(requestVO.getPageSize());
        queryParam.setPageIndex(requestVO.getPageIndex());
        queryParam.setOrderMap(requestVO.getOrderMap());
        queryParam.getParams().put("shipper_mid",new Parameter(QueryParam.EQ,requestVO.getId()));
        IPage<ShippersBankEntity> page = shippersBankService.queryPage(queryParam, false);
        IPage<ShippersBankVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ShippersBankVO.class));
        return CommonResponse.success("查询详情成功！", pageData);
    }
    /***
     * @Description 查询客户联系人列表
     * @param shippersId
     * @return
     */
    @PostMapping(value = "queryVehicleByShippersId")
    @ResponseBody
    public CommonResponse<IPage<ShippersVehicleVO>> queryVehicleByShippersId(@RequestBody RequestVO requestVO) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageSize(requestVO.getPageSize());
        queryParam.setPageIndex(requestVO.getPageIndex());
        queryParam.setOrderMap(requestVO.getOrderMap());
        queryParam.getParams().put("shipper_m_id",new Parameter(QueryParam.EQ,requestVO.getId()));
        IPage<ShippersVehicleEntity> page = shippersVehicleService.queryPage(queryParam, false);
        IPage<ShippersVehicleVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ShippersVehicleVO.class));
        return CommonResponse.success("查询详情成功！", pageData);
    }

}
